
# Getting Started with Stax (FattMerchant) API

## Introduction

API specification auto-generated from Laravel route definitions.
Base URL: https://apiprod.fattlabs.com
All routes require JWT authentication unless otherwise noted.

## Install the Package

The package is compatible with Python versions `3.7+`.
Install the package from PyPi using the following pip command:

```bash
pip install apimatic-stax-sdk==0.0.1
```

You can also view the package at:
https://pypi.python.org/pypi/apimatic-stax-sdk/0.0.1

## Initialize the API Client

**_Note:_** Documentation for the client can be found [here.](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/client.md)

The following parameters are configurable for the API Client:

| Parameter | Type | Description |
|  --- | --- | --- |
| environment | [`Environment`](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/README.md#environments) | The API environment. <br> **Default: `Environment.PRODUCTION`** |
| http_client_instance | `Union[Session, HttpClientProvider]` | The Http Client passed from the sdk user for making requests |
| override_http_client_configuration | `bool` | The value which determines to override properties of the passed Http Client from the sdk user |
| http_call_back | `HttpCallBack` | The callback value that is invoked before and after an HTTP call is made to an endpoint |
| timeout | `float` | The value to use for connection timeout. <br> **Default: 30** |
| max_retries | `int` | The number of times to retry an endpoint call if it fails. <br> **Default: 0** |
| backoff_factor | `float` | A backoff factor to apply between attempts after the second try. <br> **Default: 2** |
| retry_statuses | `Array of int` | The http statuses on which retry is to be done. <br> **Default: [408, 413, 429, 500, 502, 503, 504, 521, 522, 524]** |
| retry_methods | `Array of string` | The http methods on which retry is to be done. <br> **Default: ["GET", "PUT"]** |
| proxy_settings | [`ProxySettings`](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/proxy-settings.md) | Optional proxy configuration to route HTTP requests through a proxy server. |
| logging_configuration | [`LoggingConfiguration`](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/logging-configuration.md) | The SDK logging configuration for API calls |
| bearer_auth_credentials | [`BearerAuthCredentials`](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/auth/oauth-2-bearer-token.md) | The credential object for OAuth 2 Bearer token |

The API client can be initialized as follows:

### Code-Based Client Initialization

```python
import logging

from staxfattmerchantapi.configuration import Environment
from staxfattmerchantapi.http.auth.oauth_2 import BearerAuthCredentials
from staxfattmerchantapi.logging.configuration.api_logging_configuration import LoggingConfiguration
from staxfattmerchantapi.logging.configuration.api_logging_configuration import RequestLoggingConfiguration
from staxfattmerchantapi.logging.configuration.api_logging_configuration import ResponseLoggingConfiguration
from staxfattmerchantapi.staxfattmerchantapi_client import StaxfattmerchantapiClient

client = StaxfattmerchantapiClient(
    bearer_auth_credentials=BearerAuthCredentials(
        access_token='AccessToken'
    ),
    environment=Environment.PRODUCTION,
    logging_configuration=LoggingConfiguration(
        log_level=logging.INFO,
        request_logging_config=RequestLoggingConfiguration(
            log_body=True
        ),
        response_logging_config=ResponseLoggingConfiguration(
            log_headers=True
        )
    )
)
```

### Environment-Based Client Initialization

```python
from staxfattmerchantapi.staxfattmerchantapi_client import StaxfattmerchantapiClient

# Specify the path to your .env file if it’s located outside the project’s root directory.
client = StaxfattmerchantapiClient.from_environment(dotenv_path='/path/to/.env')
```

See the [Environment-Based Client Initialization](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/environment-based-client-initialization.md) section for details.

## Environments

The SDK can be configured to use a different environment for making API calls. Available environments are:

### Fields

| Name | Description |
|  --- | --- |
| PRODUCTION | **Default** Production |
| ENVIRONMENT2 | Development |

## Authorization

This API uses the following authentication schemes.

* [`bearerAuth (OAuth 2 Bearer token)`](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/auth/oauth-2-bearer-token.md)

## List of APIs

* [Team Users](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/team-users.md)
* [Team API Keys](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/team-api-keys.md)
* [Team Options](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/team-options.md)
* [Team Registration](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/team-registration.md)
* [Team Funding Accounts](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/team-funding-accounts.md)
* [Invoice Schedule](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/invoice-schedule.md)
* [Dispute File](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/dispute-file.md)
* [Payment Method](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/payment-method.md)
* [Merchant Admin](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/merchant-admin.md)
* [User Admin](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/user-admin.md)
* [Web Payment](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/web-payment.md)
* [Self](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/self.md)
* [Team](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/team.md)
* [Webhook](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/webhook.md)
* [Transaction](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/transaction.md)
* [Invoice](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/invoice.md)
* [Customer](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/customer.md)
* [Item](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/item.md)
* [File](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/file.md)
* [Integration](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/integration.md)
* [Hello Sign](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/hello-sign.md)
* [Reporting](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/reporting.md)
* [Charge](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/charge.md)
* [Credit](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/credit.md)
* [Verify](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/verify.md)
* [Terminal](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/terminal.md)
* [Sandbox](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/sandbox.md)
* [Cache](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/controllers/cache.md)

## SDK Infrastructure

### Configuration

* [ProxySettings](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/proxy-settings.md)
* [Environment-Based Client Initialization](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/environment-based-client-initialization.md)
* [AbstractLogger](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/abstract-logger.md)
* [LoggingConfiguration](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/logging-configuration.md)
* [RequestLoggingConfiguration](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/request-logging-configuration.md)
* [ResponseLoggingConfiguration](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/response-logging-configuration.md)

### HTTP

* [HttpResponse](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/http-response.md)
* [HttpRequest](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/http-request.md)

### Utilities

* [ApiResponse](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/api-response.md)
* [ApiHelper](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/api-helper.md)
* [HttpDateTime](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/http-date-time.md)
* [RFC3339DateTime](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/rfc3339-date-time.md)
* [UnixDateTime](https://www.github.com/sdks-io/apimatic-stax-python-sdk/tree/0.0.1/doc/unix-date-time.md)

